"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from kombo.types import BaseModel
from kombo.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class GetIntegrationsIntegrationIDRequestTypedDict(TypedDict):
    integration_id: str
    r"""GET /integrations/:integration_id Parameter"""


class GetIntegrationsIntegrationIDRequest(BaseModel):
    integration_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""GET /integrations/:integration_id Parameter"""
