"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .gettoolscategoryparametercategory import GetToolsCategoryParameterCategory
from kombo.types import BaseModel
from kombo.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class GetToolsCategoryRequestTypedDict(TypedDict):
    category: GetToolsCategoryParameterCategory
    r"""GET /tools/:category Parameter"""


class GetToolsCategoryRequest(BaseModel):
    category: Annotated[
        GetToolsCategoryParameterCategory,
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""GET /tools/:category Parameter"""
