"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .putintegrationsintegrationidenabledrequestbody import (
    PutIntegrationsIntegrationIDEnabledRequestBody,
    PutIntegrationsIntegrationIDEnabledRequestBodyTypedDict,
)
from kombo.types import BaseModel
from kombo.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class PutIntegrationsIntegrationIDEnabledRequestTypedDict(TypedDict):
    integration_id: str
    r"""PUT /integrations/:integration_id/enabled Parameter"""
    body: PutIntegrationsIntegrationIDEnabledRequestBodyTypedDict
    r"""PUT /integrations/:integration_id/enabled Request body"""


class PutIntegrationsIntegrationIDEnabledRequest(BaseModel):
    integration_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""PUT /integrations/:integration_id/enabled Parameter"""

    body: Annotated[
        PutIntegrationsIntegrationIDEnabledRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
    r"""PUT /integrations/:integration_id/enabled Request body"""
