"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from kombo.types import BaseModel
from typing_extensions import TypedDict


class PutIntegrationsIntegrationIDEnabledRequestBodyTypedDict(TypedDict):
    value: bool
    r"""The desired state of the integration (e.g., `true` for enabled, `false` for disabled)."""


class PutIntegrationsIntegrationIDEnabledRequestBody(BaseModel):
    value: bool
    r"""The desired state of the integration (e.g., `true` for enabled, `false` for disabled)."""
