"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from kombo.types import BaseModel
from kombo.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal
from typing_extensions import Annotated, TypedDict


class GetCheckAPIKeyPositiveResponseDataTypedDict(TypedDict):
    environment_id: str


class GetCheckAPIKeyPositiveResponseData(BaseModel):
    environment_id: str


class GetCheckAPIKeyPositiveResponseTypedDict(TypedDict):
    data: GetCheckAPIKeyPositiveResponseDataTypedDict
    status: Literal["success"]


class GetCheckAPIKeyPositiveResponse(BaseModel):
    data: GetCheckAPIKeyPositiveResponseData

    STATUS: Annotated[
        Annotated[Literal["success"], AfterValidator(validate_const("success"))],
        pydantic.Field(alias="status"),
    ] = "success"


try:
    GetCheckAPIKeyPositiveResponse.model_rebuild()
except NameError:
    pass
