"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from kombo.types import BaseModel
from kombo.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import List, Literal
from typing_extensions import Annotated, TypedDict


class PutAssessmentOrdersAssessmentOrderIDResultPositiveResponseDataTypedDict(
    TypedDict
):
    pass


class PutAssessmentOrdersAssessmentOrderIDResultPositiveResponseData(BaseModel):
    pass


class PutAssessmentOrdersAssessmentOrderIDResultPositiveResponseWarningTypedDict(
    TypedDict
):
    message: str


class PutAssessmentOrdersAssessmentOrderIDResultPositiveResponseWarning(BaseModel):
    message: str


class PutAssessmentOrdersAssessmentOrderIDResultPositiveResponseTypedDict(TypedDict):
    data: PutAssessmentOrdersAssessmentOrderIDResultPositiveResponseDataTypedDict
    warnings: List[
        PutAssessmentOrdersAssessmentOrderIDResultPositiveResponseWarningTypedDict
    ]
    r"""These are the interaction warnings that are shown in the dashboard. They are meant to provide debug information to you. We recommend logging them to the console."""
    status: Literal["success"]


class PutAssessmentOrdersAssessmentOrderIDResultPositiveResponse(BaseModel):
    data: PutAssessmentOrdersAssessmentOrderIDResultPositiveResponseData

    warnings: List[PutAssessmentOrdersAssessmentOrderIDResultPositiveResponseWarning]
    r"""These are the interaction warnings that are shown in the dashboard. They are meant to provide debug information to you. We recommend logging them to the console."""

    STATUS: Annotated[
        Annotated[Literal["success"], AfterValidator(validate_const("success"))],
        pydantic.Field(alias="status"),
    ] = "success"


try:
    PutAssessmentOrdersAssessmentOrderIDResultPositiveResponse.model_rebuild()
except NameError:
    pass
