"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .deleteintegrationsintegrationidrequestbody import (
    DeleteIntegrationsIntegrationIDRequestBody,
    DeleteIntegrationsIntegrationIDRequestBodyTypedDict,
)
from kombo.types import BaseModel
from kombo.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class DeleteIntegrationsIntegrationIDRequestTypedDict(TypedDict):
    integration_id: str
    r"""DELETE /integrations/:integration_id Parameter"""
    body: DeleteIntegrationsIntegrationIDRequestBodyTypedDict
    r"""DELETE /integrations/:integration_id Request body"""


class DeleteIntegrationsIntegrationIDRequest(BaseModel):
    integration_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""DELETE /integrations/:integration_id Parameter"""

    body: Annotated[
        DeleteIntegrationsIntegrationIDRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
    r"""DELETE /integrations/:integration_id Request body"""
