"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from kombo.types import BaseModel
from kombo.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import List, Literal
from typing_extensions import Annotated, TypedDict


class PutAtsApplicationsApplicationIDStagePositiveResponseDataTypedDict(TypedDict):
    pass


class PutAtsApplicationsApplicationIDStagePositiveResponseData(BaseModel):
    pass


class PutAtsApplicationsApplicationIDStagePositiveResponseWarningTypedDict(TypedDict):
    message: str


class PutAtsApplicationsApplicationIDStagePositiveResponseWarning(BaseModel):
    message: str


class PutAtsApplicationsApplicationIDStagePositiveResponseTypedDict(TypedDict):
    data: PutAtsApplicationsApplicationIDStagePositiveResponseDataTypedDict
    warnings: List[PutAtsApplicationsApplicationIDStagePositiveResponseWarningTypedDict]
    r"""These are the interaction warnings that are shown in the dashboard. They are meant to provide debug information to you. We recommend logging them to the console."""
    status: Literal["success"]


class PutAtsApplicationsApplicationIDStagePositiveResponse(BaseModel):
    data: PutAtsApplicationsApplicationIDStagePositiveResponseData

    warnings: List[PutAtsApplicationsApplicationIDStagePositiveResponseWarning]
    r"""These are the interaction warnings that are shown in the dashboard. They are meant to provide debug information to you. We recommend logging them to the console."""

    STATUS: Annotated[
        Annotated[Literal["success"], AfterValidator(validate_const("success"))],
        pydantic.Field(alias="status"),
    ] = "success"


try:
    PutAtsApplicationsApplicationIDStagePositiveResponse.model_rebuild()
except NameError:
    pass
