"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from kombo.types import BaseModel
from kombo.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import List, Literal
from typing_extensions import Annotated, TypedDict


class PostHrisEmployeesEmployeeIDDocumentsPositiveResponseDataTypedDict(TypedDict):
    pass


class PostHrisEmployeesEmployeeIDDocumentsPositiveResponseData(BaseModel):
    pass


class PostHrisEmployeesEmployeeIDDocumentsPositiveResponseWarningTypedDict(TypedDict):
    message: str


class PostHrisEmployeesEmployeeIDDocumentsPositiveResponseWarning(BaseModel):
    message: str


class PostHrisEmployeesEmployeeIDDocumentsPositiveResponseTypedDict(TypedDict):
    data: PostHrisEmployeesEmployeeIDDocumentsPositiveResponseDataTypedDict
    warnings: List[PostHrisEmployeesEmployeeIDDocumentsPositiveResponseWarningTypedDict]
    r"""These are the interaction warnings that are shown in the dashboard. They are meant to provide debug information to you. We recommend logging them to the console."""
    status: Literal["success"]


class PostHrisEmployeesEmployeeIDDocumentsPositiveResponse(BaseModel):
    data: PostHrisEmployeesEmployeeIDDocumentsPositiveResponseData

    warnings: List[PostHrisEmployeesEmployeeIDDocumentsPositiveResponseWarning]
    r"""These are the interaction warnings that are shown in the dashboard. They are meant to provide debug information to you. We recommend logging them to the console."""

    STATUS: Annotated[
        Annotated[Literal["success"], AfterValidator(validate_const("success"))],
        pydantic.Field(alias="status"),
    ] = "success"


try:
    PostHrisEmployeesEmployeeIDDocumentsPositiveResponse.model_rebuild()
except NameError:
    pass
