"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from kombo.types import BaseModel, Nullable, UNSET_SENTINEL
from pydantic import model_serializer
from typing_extensions import TypedDict


class PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDRequestBodyTypedDict(
    TypedDict
):
    integration_field_id: Nullable[str]
    r"""The integration field's unique ID which the custom field should be mapped to. Null to remove a mapping."""


class PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDRequestBody(BaseModel):
    integration_field_id: Nullable[str]
    r"""The integration field's unique ID which the custom field should be mapped to. Null to remove a mapping."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                m[k] = val

        return m
