"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .sdkerror import SDKError
from typing import Any, TYPE_CHECKING

from kombo.utils.dynamic_imports import lazy_getattr, lazy_dir

if TYPE_CHECKING:
    from .komboatserror import KomboAtsError, KomboAtsErrorData
    from .kombogeneralerror import KomboGeneralError, KomboGeneralErrorData
    from .kombohriserror import KomboHrisError, KomboHrisErrorData
    from .no_response_error import NoResponseError
    from .responsevalidationerror import ResponseValidationError
    from .sdkdefaulterror import SDKDefaultError

__all__ = [
    "KomboAtsError",
    "KomboAtsErrorData",
    "KomboGeneralError",
    "KomboGeneralErrorData",
    "KomboHrisError",
    "KomboHrisErrorData",
    "NoResponseError",
    "ResponseValidationError",
    "SDKDefaultError",
    "SDKError",
]

_dynamic_imports: dict[str, str] = {
    "KomboAtsError": ".komboatserror",
    "KomboAtsErrorData": ".komboatserror",
    "KomboGeneralError": ".kombogeneralerror",
    "KomboGeneralErrorData": ".kombogeneralerror",
    "KomboHrisError": ".kombohriserror",
    "KomboHrisErrorData": ".kombohriserror",
    "NoResponseError": ".no_response_error",
    "ResponseValidationError": ".responsevalidationerror",
    "SDKDefaultError": ".sdkdefaulterror",
}


def __getattr__(attr_name: str) -> Any:
    return lazy_getattr(
        attr_name, package=__package__, dynamic_imports=_dynamic_imports
    )


def __dir__():
    return lazy_dir(dynamic_imports=_dynamic_imports)
